==> scandeval-16.1.0.tar.gz: scandeval-16.1.0/docs/leaderboards/Monolingual/faroese.md <==
---
hide:
    - toc
---
# 🇫🇴 Faroese

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<p>
  A generative leaderboard for Faroese is not available yet, as the necessary datasets
  are not yet available.
</p>
///

/// tab | NLU Leaderboard
    select: True
<iframe title="" aria-label="Table" id="datawrapper-chart-lRosR" src="https://datawrapper.dwcdn.net/lRosR" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="849" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Performance of Language Models on Faroese NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-WyhUM" src="https://datawrapper.dwcdn.net/WyhUM/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

==> scandeval-16.5.0.tar.gz: scandeval-16.5.0/docs/leaderboards/Monolingual/faroese.md <==
---
hide:
    - toc
---
# 🇫🇴 Faroese

See the [leaderboard page](/leaderboards) for more information about all the columns.

/// tab | Generative Leaderboard
<p>
  A generative leaderboard for Faroese is not available yet, as the necessary datasets
  are not yet available.
</p>
///

/// tab | NLU Leaderboard
    select: True
<iframe title="" aria-label="Table" id="datawrapper-chart-lRosR" src="https://datawrapper.dwcdn.net/lRosR" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="849" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

/// tab | NLU Scatter Plot
<iframe title="Performance of Language Models on Faroese NLU Tasks by Model Size" aria-label="Scatter Plot" id="datawrapper-chart-WyhUM" src="https://datawrapper.dwcdn.net/WyhUM/" scrolling="no" frameborder="0" style="width: 0; min-width: 100% !important; border: none;" height="687" data-external="1"></iframe><script type="text/javascript">!function(){"use strict";window.addEventListener("message",(function(a){if(void 0!==a.data["datawrapper-height"]){var e=document.querySelectorAll("iframe");for(var t in a.data["datawrapper-height"])for(var r,i=0;r=e[i];i++)if(r.contentWindow===a.source){var d=a.data["datawrapper-height"][t]+"px";r.style.height=d}}}))}();</script>
///

<!-- This disables the requirement that all lines must be shorter than 88 characters -->
<!-- markdownlint-configure-file { "MD013": false } -->
